@@ -23,7 +23,7 @@ def main():
     if args.command == 'start':
         jupyter_command = [
             sys.executable, '-m', 'jupyter', 'lab', 
-            f'--notebook-dir={args.workspace}', f'--port={args.port}', f'--ip={args.ip}'
+            f'--notebook-dir={args.workspace}', f'--port={args.port}', f'--ip={args.ip}', '--ContentManager.allow_hidden=true'
         ]
         print(f"Running JupyterLab command: {' '.join(jupyter_command)}")
         try:
@@ -32,4 +32,4 @@ def main():
             print(f"Failed to start Amphi: {e}")
 
 if __name__ == '__main__':
-    main()
+    main()
\ No newline at end of file
